# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: variant.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='variant.proto',
  package='com.rookout',
  syntax='proto3',
  serialized_pb=_b('\n\rvariant.proto\x12\x0b\x63om.rookout\x1a\x1fgoogle/protobuf/timestamp.proto\"\x9c\x01\n\x05\x45rror\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12(\n\nparameters\x18\x03 \x01(\x0b\x32\x14.com.rookout.Variant\x12!\n\x03\x65xc\x18\x04 \x01(\x0b\x32\x14.com.rookout.Variant\x12\'\n\ttraceback\x18\x05 \x01(\x0b\x32\x14.com.rookout.Variant\"\x8a\x10\n\x07Variant\x12/\n\x0cvariant_type\x18\x01 \x01(\x0e\x32\x19.com.rookout.Variant.Type\x12\x15\n\roriginal_type\x18\x02 \x01(\t\x12\x33\n\nattributes\x18\x03 \x03(\x0b\x32\x1f.com.rookout.Variant.NamedValue\x12\x13\n\tint_value\x18\x0b \x01(\x05H\x00\x12\x14\n\nlong_value\x18\x0c \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\r \x01(\x01H\x00\x12\x33\n\x0c\x62inary_value\x18\x0e \x01(\x0b\x32\x1b.com.rookout.Variant.BinaryH\x00\x12\x33\n\x0cstring_value\x18\x0f \x01(\x0b\x32\x1b.com.rookout.Variant.StringH\x00\x12/\n\nlist_value\x18\x10 \x01(\x0b\x32\x19.com.rookout.Variant.ListH\x00\x12-\n\tmap_value\x18\x11 \x01(\x0b\x32\x18.com.rookout.Variant.MapH\x00\x12\x39\n\x0fnamespace_value\x18\x13 \x01(\x0b\x32\x1e.com.rookout.Variant.NamespaceH\x00\x12)\n\x0b\x65rror_value\x18\x14 \x01(\x0b\x32\x12.com.rookout.ErrorH\x00\x12>\n\rmessage_value\x18\x17 \x01(\x0b\x32%.com.rookout.Variant.FormattedMessageH\x00\x12\x30\n\ntime_value\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00\x12\x35\n\ncode_value\x18\x1a \x01(\x0b\x32\x1f.com.rookout.Variant.CodeObjectH\x00\x12\x38\n\x0flarge_int_value\x18\x1b \x01(\x0b\x32\x1d.com.rookout.Variant.LargeIntH\x00\x12\x35\n\rcomplex_value\x18\x1c \x01(\x0b\x32\x1c.com.rookout.Variant.ComplexH\x00\x12\x36\n\nenum_value\x18\x1f \x01(\x0b\x32 .com.rookout.Variant.EnumerationH\x00\x1a?\n\nNamedValue\x12\x0c\n\x04name\x18\x01 \x01(\t\x12#\n\x05value\x18\x02 \x01(\x0b\x32\x14.com.rookout.Variant\x1a.\n\x06\x42inary\x12\x15\n\roriginal_size\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\x0c\x1a.\n\x06String\x12\x15\n\roriginal_size\x18\x01 \x01(\x05\x12\r\n\x05value\x18\x02 \x01(\t\x1aQ\n\x04List\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x15\n\roriginal_size\x18\x02 \x01(\x05\x12$\n\x06values\x18\x03 \x03(\x0b\x32\x14.com.rookout.Variant\x1aQ\n\x04Pair\x12#\n\x05\x66irst\x18\x01 \x01(\x0b\x32\x14.com.rookout.Variant\x12$\n\x06second\x18\x02 \x01(\x0b\x32\x14.com.rookout.Variant\x1a\x46\n\x03Map\x12\x15\n\roriginal_size\x18\x01 \x01(\x05\x12(\n\x05pairs\x18\x02 \x03(\x0b\x32\x19.com.rookout.Variant.Pair\x1a@\n\tNamespace\x12\x33\n\nattributes\x18\x01 \x03(\x0b\x32\x1f.com.rookout.Variant.NamedValue\x1a#\n\x10\x46ormattedMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x1aL\n\nCodeObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06module\x18\x02 \x01(\t\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\x12\x0e\n\x06lineno\x18\x04 \x01(\r\x1a\x19\n\x08LargeInt\x12\r\n\x05value\x18\x01 \x01(\t\x1a*\n\x07\x43omplex\x12\x0c\n\x04real\x18\x01 \x01(\x01\x12\x11\n\timaginary\x18\x02 \x01(\x01\x1aM\n\x0b\x45numeration\x12\x14\n\x0cstring_value\x18\x01 \x01(\t\x12\x15\n\rordinal_value\x18\x02 \x01(\x05\x12\x11\n\ttype_name\x18\x03 \x01(\t\"\xd9\x03\n\x04Type\x12\x10\n\x0cVARIANT_NONE\x10\x00\x12\x0f\n\x0bVARIANT_INT\x10\x01\x12\x10\n\x0cVARIANT_LONG\x10\x02\x12\x12\n\x0eVARIANT_DOUBLE\x10\x03\x12\x12\n\x0eVARIANT_BINARY\x10\x04\x12\x12\n\x0eVARIANT_STRING\x10\x05\x12\x10\n\x0cVARIANT_LIST\x10\x06\x12\x0f\n\x0bVARIANT_MAP\x10\x07\x12\x12\n\x0eVARIANT_OBJECT\x10\x08\x12\x15\n\x11VARIANT_NAMESPACE\x10\t\x12\x11\n\rVARIANT_ERROR\x10\n\x12\x19\n\x15VARIANT_NOT_SUPPORTED\x10\x0b\x12\x15\n\x11VARIANT_MAX_DEPTH\x10\x0c\x12\x1d\n\x19VARIANT_FORMATTED_MESSAGE\x10\r\x12\x10\n\x0cVARIANT_TIME\x10\x0e\x12\x19\n\x15VARIANT_UKNOWN_OBJECT\x10\x0f\x12\x17\n\x13VARIANT_CODE_OBJECT\x10\x10\x12\x15\n\x11VARIANT_LARGE_INT\x10\x11\x12\x13\n\x0fVARIANT_COMPLEX\x10\x12\x12\x15\n\x11VARIANT_UNDEFINED\x10\x13\x12\x13\n\x0fVARIANT_DYNAMIC\x10\x14\x12\x10\n\x0cVARIANT_ENUM\x10\x15\x42\x07\n\x05valueb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_VARIANT_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='com.rookout.Variant.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='VARIANT_NONE', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_INT', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_LONG', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_DOUBLE', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_BINARY', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_STRING', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_LIST', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_MAP', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_OBJECT', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_NAMESPACE', index=9, number=9,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_ERROR', index=10, number=10,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_NOT_SUPPORTED', index=11, number=11,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_MAX_DEPTH', index=12, number=12,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_FORMATTED_MESSAGE', index=13, number=13,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_TIME', index=14, number=14,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_UKNOWN_OBJECT', index=15, number=15,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_CODE_OBJECT', index=16, number=16,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_LARGE_INT', index=17, number=17,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_COMPLEX', index=18, number=18,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_UNDEFINED', index=19, number=19,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_DYNAMIC', index=20, number=20,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VARIANT_ENUM', index=21, number=21,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1799,
  serialized_end=2272,
)
_sym_db.RegisterEnumDescriptor(_VARIANT_TYPE)


_ERROR = _descriptor.Descriptor(
  name='Error',
  full_name='com.rookout.Error',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.Error.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type', full_name='com.rookout.Error.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='com.rookout.Error.parameters', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='exc', full_name='com.rookout.Error.exc', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='traceback', full_name='com.rookout.Error.traceback', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=64,
  serialized_end=220,
)


_VARIANT_NAMEDVALUE = _descriptor.Descriptor(
  name='NamedValue',
  full_name='com.rookout.Variant.NamedValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.rookout.Variant.NamedValue.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.Variant.NamedValue.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1131,
)

_VARIANT_BINARY = _descriptor.Descriptor(
  name='Binary',
  full_name='com.rookout.Variant.Binary',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='original_size', full_name='com.rookout.Variant.Binary.original_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.Variant.Binary.value', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1133,
  serialized_end=1179,
)

_VARIANT_STRING = _descriptor.Descriptor(
  name='String',
  full_name='com.rookout.Variant.String',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='original_size', full_name='com.rookout.Variant.String.original_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.Variant.String.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1181,
  serialized_end=1227,
)

_VARIANT_LIST = _descriptor.Descriptor(
  name='List',
  full_name='com.rookout.Variant.List',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='com.rookout.Variant.List.type', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_size', full_name='com.rookout.Variant.List.original_size', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='values', full_name='com.rookout.Variant.List.values', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1229,
  serialized_end=1310,
)

_VARIANT_PAIR = _descriptor.Descriptor(
  name='Pair',
  full_name='com.rookout.Variant.Pair',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='first', full_name='com.rookout.Variant.Pair.first', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='second', full_name='com.rookout.Variant.Pair.second', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1312,
  serialized_end=1393,
)

_VARIANT_MAP = _descriptor.Descriptor(
  name='Map',
  full_name='com.rookout.Variant.Map',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='original_size', full_name='com.rookout.Variant.Map.original_size', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='pairs', full_name='com.rookout.Variant.Map.pairs', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1395,
  serialized_end=1465,
)

_VARIANT_NAMESPACE = _descriptor.Descriptor(
  name='Namespace',
  full_name='com.rookout.Variant.Namespace',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='attributes', full_name='com.rookout.Variant.Namespace.attributes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1467,
  serialized_end=1531,
)

_VARIANT_FORMATTEDMESSAGE = _descriptor.Descriptor(
  name='FormattedMessage',
  full_name='com.rookout.Variant.FormattedMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='com.rookout.Variant.FormattedMessage.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1533,
  serialized_end=1568,
)

_VARIANT_CODEOBJECT = _descriptor.Descriptor(
  name='CodeObject',
  full_name='com.rookout.Variant.CodeObject',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='com.rookout.Variant.CodeObject.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='module', full_name='com.rookout.Variant.CodeObject.module', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='filename', full_name='com.rookout.Variant.CodeObject.filename', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='lineno', full_name='com.rookout.Variant.CodeObject.lineno', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1570,
  serialized_end=1646,
)

_VARIANT_LARGEINT = _descriptor.Descriptor(
  name='LargeInt',
  full_name='com.rookout.Variant.LargeInt',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='com.rookout.Variant.LargeInt.value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1648,
  serialized_end=1673,
)

_VARIANT_COMPLEX = _descriptor.Descriptor(
  name='Complex',
  full_name='com.rookout.Variant.Complex',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='real', full_name='com.rookout.Variant.Complex.real', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='imaginary', full_name='com.rookout.Variant.Complex.imaginary', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1675,
  serialized_end=1717,
)

_VARIANT_ENUMERATION = _descriptor.Descriptor(
  name='Enumeration',
  full_name='com.rookout.Variant.Enumeration',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='string_value', full_name='com.rookout.Variant.Enumeration.string_value', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='ordinal_value', full_name='com.rookout.Variant.Enumeration.ordinal_value', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='type_name', full_name='com.rookout.Variant.Enumeration.type_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1719,
  serialized_end=1796,
)

_VARIANT = _descriptor.Descriptor(
  name='Variant',
  full_name='com.rookout.Variant',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='variant_type', full_name='com.rookout.Variant.variant_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='original_type', full_name='com.rookout.Variant.original_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='attributes', full_name='com.rookout.Variant.attributes', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='int_value', full_name='com.rookout.Variant.int_value', index=3,
      number=11, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='long_value', full_name='com.rookout.Variant.long_value', index=4,
      number=12, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='com.rookout.Variant.double_value', index=5,
      number=13, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='binary_value', full_name='com.rookout.Variant.binary_value', index=6,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='com.rookout.Variant.string_value', index=7,
      number=15, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='list_value', full_name='com.rookout.Variant.list_value', index=8,
      number=16, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='map_value', full_name='com.rookout.Variant.map_value', index=9,
      number=17, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='namespace_value', full_name='com.rookout.Variant.namespace_value', index=10,
      number=19, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='error_value', full_name='com.rookout.Variant.error_value', index=11,
      number=20, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message_value', full_name='com.rookout.Variant.message_value', index=12,
      number=23, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_value', full_name='com.rookout.Variant.time_value', index=13,
      number=24, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='code_value', full_name='com.rookout.Variant.code_value', index=14,
      number=26, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='large_int_value', full_name='com.rookout.Variant.large_int_value', index=15,
      number=27, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='complex_value', full_name='com.rookout.Variant.complex_value', index=16,
      number=28, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='enum_value', full_name='com.rookout.Variant.enum_value', index=17,
      number=31, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_VARIANT_NAMEDVALUE, _VARIANT_BINARY, _VARIANT_STRING, _VARIANT_LIST, _VARIANT_PAIR, _VARIANT_MAP, _VARIANT_NAMESPACE, _VARIANT_FORMATTEDMESSAGE, _VARIANT_CODEOBJECT, _VARIANT_LARGEINT, _VARIANT_COMPLEX, _VARIANT_ENUMERATION, ],
  enum_types=[
    _VARIANT_TYPE,
  ],
  options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='com.rookout.Variant.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=223,
  serialized_end=2281,
)

_ERROR.fields_by_name['parameters'].message_type = _VARIANT
_ERROR.fields_by_name['exc'].message_type = _VARIANT
_ERROR.fields_by_name['traceback'].message_type = _VARIANT
_VARIANT_NAMEDVALUE.fields_by_name['value'].message_type = _VARIANT
_VARIANT_NAMEDVALUE.containing_type = _VARIANT
_VARIANT_BINARY.containing_type = _VARIANT
_VARIANT_STRING.containing_type = _VARIANT
_VARIANT_LIST.fields_by_name['values'].message_type = _VARIANT
_VARIANT_LIST.containing_type = _VARIANT
_VARIANT_PAIR.fields_by_name['first'].message_type = _VARIANT
_VARIANT_PAIR.fields_by_name['second'].message_type = _VARIANT
_VARIANT_PAIR.containing_type = _VARIANT
_VARIANT_MAP.fields_by_name['pairs'].message_type = _VARIANT_PAIR
_VARIANT_MAP.containing_type = _VARIANT
_VARIANT_NAMESPACE.fields_by_name['attributes'].message_type = _VARIANT_NAMEDVALUE
_VARIANT_NAMESPACE.containing_type = _VARIANT
_VARIANT_FORMATTEDMESSAGE.containing_type = _VARIANT
_VARIANT_CODEOBJECT.containing_type = _VARIANT
_VARIANT_LARGEINT.containing_type = _VARIANT
_VARIANT_COMPLEX.containing_type = _VARIANT
_VARIANT_ENUMERATION.containing_type = _VARIANT
_VARIANT.fields_by_name['variant_type'].enum_type = _VARIANT_TYPE
_VARIANT.fields_by_name['attributes'].message_type = _VARIANT_NAMEDVALUE
_VARIANT.fields_by_name['binary_value'].message_type = _VARIANT_BINARY
_VARIANT.fields_by_name['string_value'].message_type = _VARIANT_STRING
_VARIANT.fields_by_name['list_value'].message_type = _VARIANT_LIST
_VARIANT.fields_by_name['map_value'].message_type = _VARIANT_MAP
_VARIANT.fields_by_name['namespace_value'].message_type = _VARIANT_NAMESPACE
_VARIANT.fields_by_name['error_value'].message_type = _ERROR
_VARIANT.fields_by_name['message_value'].message_type = _VARIANT_FORMATTEDMESSAGE
_VARIANT.fields_by_name['time_value'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_VARIANT.fields_by_name['code_value'].message_type = _VARIANT_CODEOBJECT
_VARIANT.fields_by_name['large_int_value'].message_type = _VARIANT_LARGEINT
_VARIANT.fields_by_name['complex_value'].message_type = _VARIANT_COMPLEX
_VARIANT.fields_by_name['enum_value'].message_type = _VARIANT_ENUMERATION
_VARIANT_TYPE.containing_type = _VARIANT
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['int_value'])
_VARIANT.fields_by_name['int_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['long_value'])
_VARIANT.fields_by_name['long_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['double_value'])
_VARIANT.fields_by_name['double_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['binary_value'])
_VARIANT.fields_by_name['binary_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['string_value'])
_VARIANT.fields_by_name['string_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['list_value'])
_VARIANT.fields_by_name['list_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['map_value'])
_VARIANT.fields_by_name['map_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['namespace_value'])
_VARIANT.fields_by_name['namespace_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['error_value'])
_VARIANT.fields_by_name['error_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['message_value'])
_VARIANT.fields_by_name['message_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['time_value'])
_VARIANT.fields_by_name['time_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['code_value'])
_VARIANT.fields_by_name['code_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['large_int_value'])
_VARIANT.fields_by_name['large_int_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['complex_value'])
_VARIANT.fields_by_name['complex_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
_VARIANT.oneofs_by_name['value'].fields.append(
  _VARIANT.fields_by_name['enum_value'])
_VARIANT.fields_by_name['enum_value'].containing_oneof = _VARIANT.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['Error'] = _ERROR
DESCRIPTOR.message_types_by_name['Variant'] = _VARIANT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Error = _reflection.GeneratedProtocolMessageType('Error', (_message.Message,), dict(
  DESCRIPTOR = _ERROR,
  __module__ = 'variant_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Error)
  ))
_sym_db.RegisterMessage(Error)

Variant = _reflection.GeneratedProtocolMessageType('Variant', (_message.Message,), dict(

  NamedValue = _reflection.GeneratedProtocolMessageType('NamedValue', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_NAMEDVALUE,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.NamedValue)
    ))
  ,

  Binary = _reflection.GeneratedProtocolMessageType('Binary', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_BINARY,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Binary)
    ))
  ,

  String = _reflection.GeneratedProtocolMessageType('String', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_STRING,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.String)
    ))
  ,

  List = _reflection.GeneratedProtocolMessageType('List', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_LIST,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.List)
    ))
  ,

  Pair = _reflection.GeneratedProtocolMessageType('Pair', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_PAIR,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Pair)
    ))
  ,

  Map = _reflection.GeneratedProtocolMessageType('Map', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_MAP,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Map)
    ))
  ,

  Namespace = _reflection.GeneratedProtocolMessageType('Namespace', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_NAMESPACE,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Namespace)
    ))
  ,

  FormattedMessage = _reflection.GeneratedProtocolMessageType('FormattedMessage', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_FORMATTEDMESSAGE,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.FormattedMessage)
    ))
  ,

  CodeObject = _reflection.GeneratedProtocolMessageType('CodeObject', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_CODEOBJECT,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.CodeObject)
    ))
  ,

  LargeInt = _reflection.GeneratedProtocolMessageType('LargeInt', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_LARGEINT,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.LargeInt)
    ))
  ,

  Complex = _reflection.GeneratedProtocolMessageType('Complex', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_COMPLEX,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Complex)
    ))
  ,

  Enumeration = _reflection.GeneratedProtocolMessageType('Enumeration', (_message.Message,), dict(
    DESCRIPTOR = _VARIANT_ENUMERATION,
    __module__ = 'variant_pb2'
    # @@protoc_insertion_point(class_scope:com.rookout.Variant.Enumeration)
    ))
  ,
  DESCRIPTOR = _VARIANT,
  __module__ = 'variant_pb2'
  # @@protoc_insertion_point(class_scope:com.rookout.Variant)
  ))
_sym_db.RegisterMessage(Variant)
_sym_db.RegisterMessage(Variant.NamedValue)
_sym_db.RegisterMessage(Variant.Binary)
_sym_db.RegisterMessage(Variant.String)
_sym_db.RegisterMessage(Variant.List)
_sym_db.RegisterMessage(Variant.Pair)
_sym_db.RegisterMessage(Variant.Map)
_sym_db.RegisterMessage(Variant.Namespace)
_sym_db.RegisterMessage(Variant.FormattedMessage)
_sym_db.RegisterMessage(Variant.CodeObject)
_sym_db.RegisterMessage(Variant.LargeInt)
_sym_db.RegisterMessage(Variant.Complex)
_sym_db.RegisterMessage(Variant.Enumeration)


# @@protoc_insertion_point(module_scope)
